@@ -60,7 +60,8 @@
 #' @importFrom grDevices nclass.Sturges
 #' @importFrom stats complete.cases sd median quantile model.frame model.matrix
 #'   model.offset terms optim pbinom dbinom qbinom as.formula update.formula
-#'   weighted.mean runif dunif plogis pnorm qlogis qnorm uniroot
+#'   weighted.mean runif dunif plogis pnorm qlogis qnorm uniroot update var
+#'   setNames
 #' @importFrom utils packageVersion head
 #' @importFrom RcppParallel CxxFlags
 #' @importFrom rstantools rstan_config
@@ -72,3 +73,8 @@ NULL
 
 # Stop R CMD check thinking . used in pipes is an undeclared global variable
 if (getRversion() >= "2.15.1")  utils::globalVariables(c("."))
+
+# Reexport survival::Surv()
+#' @importFrom survival Surv
+#' @export
+survival::Surv
